@@ -1,5 +1,5 @@
 #!/usr/bin/python
-
+# vim: set fileencoding=utf8:
 # GNU Solfege - free ear training software
 # Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008  Tom Cato Amundsen
 #
@@ -18,6 +18,7 @@
 
 # This script is used to launch Solfege when running
 # it from the source dir without installing.
+from __future__ import absolute_import
 import __builtin__
 import time
 __builtin__.start_time = time.time()
@@ -26,10 +27,11 @@ import sys
 import os
 import os.path
 import shutil
-import src
-import src.cfg
+import traceback
+import textwrap
 
-from src import filesystem
+from solfege import cfg
+from solfege import filesystem
 
 if sys.platform == 'win32':
     # Migration added in solfege 3.9.0.
@@ -53,25 +55,27 @@ if not os.path.exists(filesystem.user_data()):
     os.makedirs(filesystem.user_data())
 
 try:
-    src.cfg.initialise("default.config", None, filesystem.rcfile())
+    cfg.initialise("default.config", None, filesystem.rcfile())
 except UnicodeDecodeError, e:
-    import traceback
     traceback.print_exc()
-    print "\n\tYou .solfegerc file is not properly utf8 encoded. Most likely"
-    print "\tit is the path to some external program that contain non-ascii"
-    print "\tcharacters. Please edit or delete the file. Or email it to"
-    print "\ttca@gnu.org, and he will tell you what the problem is.\n"
-    sys.exit(-1)
+    print >> sys.stderr
+    print >> sys.stderr, "\n".join(textwrap.wrap(
+          "Your %s file is not properly utf8 encoded. Most likely"
+          " it is the path to some external program that contain non-ascii"
+          " characters. Please edit or delete the file. Or email it to"
+          " tca@gnu.org, and he will tell you what the problem is." % filesystem.rcfile().encode("ascii", "backslashreplace")))
+    print >> sys.stderr
+    sys.exit("I give up (solfege.py)")
 
 
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
-import src.i18n
+import solfege.i18n
 # MIGRATION from 2.9.2 to 2.9.3
-if src.cfg.get_string("app/lc_messages") == 'C (english)':
-    src.cfg.set_string("app/lc_messages", "C")
-src.i18n.setup(".", src.cfg.get_string("app/lc_messages"))
+if cfg.get_string("app/lc_messages") == 'C (english)':
+    cfg.set_string("app/lc_messages", "C")
+solfege.i18n.setup(".", cfg.get_string("app/lc_messages"))
 
-import src.mainwin
+import solfege.startup
 
-src.mainwin.start_app(".")
+solfege.startup.start_app(".")
